==> exif-0.6.0.tar.gz: exif-0.6.0/exif/tests/modify_exif_baselines/modify_user_comment.py <==
"""APP1 segment hexadecimal baseline for test_modify in test_user_comment module."""

from baseline import Baseline

MODIFY_USER_COMMENT_BASELINE = Baseline("""
    FFE103D84578696600004D4D002A00000008000601030003000000010006000001120003000000010001000001
    1A00050000000100000056011B0005000000010000005E01280003000000010002000087690004000000010000
    00660000010E00000048000000010000004800000001000492860007000000710000009CA00100030000000100
    010000A00200040000000100000006A00300040000000100000006000000004153434949000000557064617465
    64207573657220636f6d6d656e742e000000000000000000000000000000000000000000000000000000000000
    000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
    000000000000000000000006010300030000000100060000011A0005000000010000015C011B00050000000100
    00016401280003000000010002000002010004000000010000016C020200040000000100000263000000000000
    0048000000010000004800000001FFD8FFDB004300080606070605080707070909080A0C140D0C0B0B0C191213
    0F141D1A1F1E1D1A1C1C20242E2720222C231C1C2837292C30313434341F27393D38323C2E333432FFDB004301
    0909090C0B0C180D0D1832211C2132323232323232323232323232323232323232323232323232323232323232
    32323232323232323232323232323232323232FFC00011080001000103012100021101031101FFC4001F000001
    0501010101010100000000000000000102030405060708090A0BFFC400B5100002010303020403050504040000
    017D01020300041105122131410613516107227114328191A1082342B1C11552D1F02433627282090A16171819
    1A25262728292A3435363738393A434445464748494A535455565758595A636465666768696A73747576777879
    7A838485868788898A92939495969798999AA2A3A4A5A6A7A8A9AAB2B3B4B5B6B7B8B9BAC2C3C4C5C6C7C8C9CA
    D2D3D4D5D6D7D8D9DAE1E2E3E4E5E6E7E8E9EAF1F2F3F4F5F6F7F8F9FAFFC4001F010003010101010101010101
    0000000000000102030405060708090A0BFFC400B5110002010204040304070504040001027700010203110405
    2131061241510761711322328108144291A1B1C109233352F0156272D10A162434E125F11718191A262728292A
    35363738393A434445464748494A535455565758595A636465666768696A737475767778797A82838485868788
    898A92939495969798999AA2A3A4A5A6A7A8A9AAB2B3B4B5B6B7B8B9BAC2C3C4C5C6C7C8C9CAD2D3D4D5D6D7D8
    D9DAE2E3E4E5E6E7E8E9EAF2F3F4F5F6F7F8F9FAFFDA000C03010002110311003F00F9FE8A00FF
    """)

==> exif-1.0.1.tar.gz: exif-1.0.1/exif/tests/modify_exif_baselines/modify_user_comment.py <==
"""APP1 segment hexadecimal baseline for test_modify in test_user_comment module."""

from baseline import Baseline

MODIFY_USER_COMMENT_BASELINE = Baseline("""
    FFE103D84578696600004D4D002A00000008000601030003000000010006000001120003000000010001000001
    1A00050000000100000056011B0005000000010000005E01280003000000010002000087690004000000010000
    00660000010E000000480000000100000048000000010004928600070000001D0000009CA00100030000000100
    010000A00200040000000100000006A00300040000000100000006000000004153434949000000557064617465
    64207573657220636F6D6D656E742E000000000000000000000000000000000000000000000000000000000000
    000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
    000000000000000000000006010300030000000100060000011A0005000000010000015C011B00050000000100
    00016401280003000000010002000002010004000000010000016C020200040000000100000263000000000000
    0048000000010000004800000001FFD8FFDB004300080606070605080707070909080A0C140D0C0B0B0C191213
    0F141D1A1F1E1D1A1C1C20242E2720222C231C1C2837292C30313434341F27393D38323C2E333432FFDB004301
    0909090C0B0C180D0D1832211C2132323232323232323232323232323232323232323232323232323232323232
    32323232323232323232323232323232323232FFC00011080001000103012100021101031101FFC4001F000001
    0501010101010100000000000000000102030405060708090A0BFFC400B5100002010303020403050504040000
    017D01020300041105122131410613516107227114328191A1082342B1C11552D1F02433627282090A16171819
    1A25262728292A3435363738393A434445464748494A535455565758595A636465666768696A73747576777879
    7A838485868788898A92939495969798999AA2A3A4A5A6A7A8A9AAB2B3B4B5B6B7B8B9BAC2C3C4C5C6C7C8C9CA
    D2D3D4D5D6D7D8D9DAE1E2E3E4E5E6E7E8E9EAF1F2F3F4F5F6F7F8F9FAFFC4001F010003010101010101010101
    0000000000000102030405060708090A0BFFC400B5110002010204040304070504040001027700010203110405
    2131061241510761711322328108144291A1B1C109233352F0156272D10A162434E125F11718191A262728292A
    35363738393A434445464748494A535455565758595A636465666768696A737475767778797A82838485868788
    898A92939495969798999AA2A3A4A5A6A7A8A9AAB2B3B4B5B6B7B8B9BAC2C3C4C5C6C7C8C9CAD2D3D4D5D6D7D8
    D9DAE2E3E4E5E6E7E8E9EAF2F3F4F5F6F7F8F9FAFFDA000C03010002110311003F00F9FE8A00FFD9
    """)
